@@ -474,6 +474,7 @@ sub ourBuildTextures
   if ($hasImage && -e $Tex_File)
   {
     my $img = new OpenGL::Image(source=>$Tex_File);
+    die $@ if $@;
     my($eng,$ver) = $img->Get('engine','version');
     print "Using OpenGL::Image - $eng v$ver\n";
 
@@ -641,7 +642,7 @@ sub ourBuildTextures
     glFramebufferTexture2DEXT(GL_FRAMEBUFFER_EXT, GL_COLOR_ATTACHMENT0_EXT,
       GL_TEXTURE_2D, $TextureID_FBO, 0);
     glBindRenderbufferEXT(GL_RENDERBUFFER_EXT, $RenderBufferID);
-    glRenderbufferStorageEXT(GL_RENDERBUFFER_EXT, GL_DEPTH_COMPONENT24,
+    glRenderbufferStorageEXT(GL_RENDERBUFFER_EXT, GL_DEPTH_COMPONENT24_ARB,
       $Tex_Width, $Tex_Height);
     glFramebufferRenderbufferEXT(GL_FRAMEBUFFER_EXT, GL_DEPTH_ATTACHMENT_EXT,
       GL_RENDERBUFFER_EXT, $RenderBufferID);
@@ -1161,6 +1162,7 @@ sub Save
 # Cleanup routine
 sub ourCleanup
 {
+  print "Starting cleanup ...\n";
   # Disable app
   glutHideWindow();
   glutKeyboardUpFunc();
@@ -1175,13 +1177,16 @@ sub ourCleanup
   # Now you can destroy window
   if (defined($gameMode))
   {
+    print "Leaving game mode.\n";
     glutLeaveGameMode();
   }
   else
   {
+    print "Destroying window.\n";
     glutDestroyWindow($Window_ID);
   }
   undef($Window_ID);
+  print "Cleanup completed.\n";
 }
 
 sub ReleaseResources
@@ -1635,6 +1640,7 @@ Press 'c' to capture/save a RGBA targa file.
 # Pass off control to OpenGL.
 # Above functions are called as appropriate.
 if (Acme::MITHALDU::BleedingOpenGL::_have_freeglut()) {
+   print "Setting window close to trigger return from mainloop.\n";
    glutSetOption(GLUT_ACTION_ON_WINDOW_CLOSE,GLUT_ACTION_GLUTMAINLOOP_RETURNS)
 }
 
